# -*- coding: utf-8 -*-
# Generated by https://github.com/verloop/twirpy/protoc-gen-twirpy.  DO NOT EDIT!
# source: video/sfu/signal_rpc/signal.proto

from google.protobuf import symbol_database as _symbol_database

from twirp.base import Endpoint
from twirp.server import TwirpServer
from twirp.client import TwirpClient

_sym_db = _symbol_database.Default()

class SignalServerServer(TwirpServer):

	def __init__(self, *args, service, server_path_prefix="/twirp"):
		super().__init__(service=service)
		self._prefix = F"{server_path_prefix}/stream.video.sfu.signal.SignalServer"
		self._endpoints = {
			"SetPublisher": Endpoint(
				service_name="SignalServer",
				name="SetPublisher",
				function=getattr(service, "SetPublisher"),
				input=_sym_db.GetSymbol("stream.video.sfu.signal.SetPublisherRequest"),
				output=_sym_db.GetSymbol("stream.video.sfu.signal.SetPublisherResponse"),
			),
			"SendAnswer": Endpoint(
				service_name="SignalServer",
				name="SendAnswer",
				function=getattr(service, "SendAnswer"),
				input=_sym_db.GetSymbol("stream.video.sfu.signal.SendAnswerRequest"),
				output=_sym_db.GetSymbol("stream.video.sfu.signal.SendAnswerResponse"),
			),
			"IceTrickle": Endpoint(
				service_name="SignalServer",
				name="IceTrickle",
				function=getattr(service, "IceTrickle"),
				input=_sym_db.GetSymbol("stream.video.sfu.models.ICETrickle"),
				output=_sym_db.GetSymbol("stream.video.sfu.signal.ICETrickleResponse"),
			),
			"UpdateSubscriptions": Endpoint(
				service_name="SignalServer",
				name="UpdateSubscriptions",
				function=getattr(service, "UpdateSubscriptions"),
				input=_sym_db.GetSymbol("stream.video.sfu.signal.UpdateSubscriptionsRequest"),
				output=_sym_db.GetSymbol("stream.video.sfu.signal.UpdateSubscriptionsResponse"),
			),
			"UpdateMuteState": Endpoint(
				service_name="SignalServer",
				name="UpdateMuteState",
				function=getattr(service, "UpdateMuteState"),
				input=_sym_db.GetSymbol("stream.video.sfu.signal.UpdateMuteStateRequest"),
				output=_sym_db.GetSymbol("stream.video.sfu.signal.UpdateMuteStateResponse"),
			),
			"RequestVideoQuality": Endpoint(
				service_name="SignalServer",
				name="RequestVideoQuality",
				function=getattr(service, "RequestVideoQuality"),
				input=_sym_db.GetSymbol("stream.video.sfu.signal.UpdateVideoQualityRequest"),
				output=_sym_db.GetSymbol("stream.video.sfu.signal.UpdateVideoQualityResponse"),
			),
		}

class SignalServerClient(TwirpClient):

	def SetPublisher(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.sfu.signal.SignalServer/SetPublisher",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.sfu.signal.SetPublisherResponse"),
			**kwargs,
		)

	def SendAnswer(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.sfu.signal.SignalServer/SendAnswer",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.sfu.signal.SendAnswerResponse"),
			**kwargs,
		)

	def IceTrickle(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.sfu.signal.SignalServer/IceTrickle",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.sfu.signal.ICETrickleResponse"),
			**kwargs,
		)

	def UpdateSubscriptions(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.sfu.signal.SignalServer/UpdateSubscriptions",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.sfu.signal.UpdateSubscriptionsResponse"),
			**kwargs,
		)

	def UpdateMuteState(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.sfu.signal.SignalServer/UpdateMuteState",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.sfu.signal.UpdateMuteStateResponse"),
			**kwargs,
		)

	def RequestVideoQuality(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.sfu.signal.SignalServer/RequestVideoQuality",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.sfu.signal.UpdateVideoQualityResponse"),
			**kwargs,
		)



# -*- coding: utf-8 -*-
# Generated by https://github.com/verloop/twirpy/protoc-gen-twirpy.  DO NOT EDIT!
# source: video/coordinator/server_v1_rpc/server_rpc.proto

from google.protobuf import symbol_database as _symbol_database

from twirp.base import Endpoint
from twirp.server import TwirpServer
from twirp.client import TwirpClient

_sym_db = _symbol_database.Default()

class ServerRPCServer(TwirpServer):

	def __init__(self, *args, service, server_path_prefix="/twirp"):
		super().__init__(service=service)
		self._prefix = F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC"
		self._endpoints = {
			"GetApp": Endpoint(
				service_name="ServerRPC",
				name="GetApp",
				function=getattr(service, "GetApp"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.GetAppRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.GetAppResponse"),
			),
			"UpdateApp": Endpoint(
				service_name="ServerRPC",
				name="UpdateApp",
				function=getattr(service, "UpdateApp"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.UpdateAppRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.UpdateAppResponse"),
			),
			"CreateCallType": Endpoint(
				service_name="ServerRPC",
				name="CreateCallType",
				function=getattr(service, "CreateCallType"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.CreateCallTypeRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.CreateCallTypeResponse"),
			),
			"GetCallType": Endpoint(
				service_name="ServerRPC",
				name="GetCallType",
				function=getattr(service, "GetCallType"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.GetCallTypeRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.GetCallTypeResponse"),
			),
			"QueryCallTypes": Endpoint(
				service_name="ServerRPC",
				name="QueryCallTypes",
				function=getattr(service, "QueryCallTypes"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.QueryCallTypesRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.QueryCallTypesResponse"),
			),
			"UpdateCallType": Endpoint(
				service_name="ServerRPC",
				name="UpdateCallType",
				function=getattr(service, "UpdateCallType"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.UpdateCallTypeRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.UpdateCallTypeResponse"),
			),
			"DeleteCallType": Endpoint(
				service_name="ServerRPC",
				name="DeleteCallType",
				function=getattr(service, "DeleteCallType"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.DeleteCallTypeRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.DeleteCallTypeResponse"),
			),
			"CreatePushProvider": Endpoint(
				service_name="ServerRPC",
				name="CreatePushProvider",
				function=getattr(service, "CreatePushProvider"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.CreatePushProviderRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.CreatePushProviderResponse"),
			),
			"GetPushProvider": Endpoint(
				service_name="ServerRPC",
				name="GetPushProvider",
				function=getattr(service, "GetPushProvider"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.GetPushProviderRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.GetPushProviderResponse"),
			),
			"QueryPushProviders": Endpoint(
				service_name="ServerRPC",
				name="QueryPushProviders",
				function=getattr(service, "QueryPushProviders"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.QueryPushProvidersRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.QueryPushProvidersResponse"),
			),
			"UpdatePushProvider": Endpoint(
				service_name="ServerRPC",
				name="UpdatePushProvider",
				function=getattr(service, "UpdatePushProvider"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.UpdatePushProviderRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.UpdatePushProviderResponse"),
			),
			"DeletePushProvider": Endpoint(
				service_name="ServerRPC",
				name="DeletePushProvider",
				function=getattr(service, "DeletePushProvider"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.DeletePushProviderRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.DeletePushProviderResponse"),
			),
			"StartBroadcast": Endpoint(
				service_name="ServerRPC",
				name="StartBroadcast",
				function=getattr(service, "StartBroadcast"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.StartBroadcastRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.StartBroadcastResponse"),
			),
			"StopBroadcast": Endpoint(
				service_name="ServerRPC",
				name="StopBroadcast",
				function=getattr(service, "StopBroadcast"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.StopBroadcastRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.StopBroadcastResponse"),
			),
			"StartRecording": Endpoint(
				service_name="ServerRPC",
				name="StartRecording",
				function=getattr(service, "StartRecording"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.StartRecordingRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.StartRecordingResponse"),
			),
			"StopRecording": Endpoint(
				service_name="ServerRPC",
				name="StopRecording",
				function=getattr(service, "StopRecording"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.StopRecordingRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.StopRecordingResponse"),
			),
			"GetRecordings": Endpoint(
				service_name="ServerRPC",
				name="GetRecordings",
				function=getattr(service, "GetRecordings"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.GetRecordingsRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.GetRecordingsResponse"),
			),
			"DeleteRecording": Endpoint(
				service_name="ServerRPC",
				name="DeleteRecording",
				function=getattr(service, "DeleteRecording"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.DeleteRecordingRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.DeleteRecordingResponse"),
			),
			"QueryCallTimelineEvents": Endpoint(
				service_name="ServerRPC",
				name="QueryCallTimelineEvents",
				function=getattr(service, "QueryCallTimelineEvents"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.QueryCallTimelineEventsRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.QueryCallTimelineEventsResponse"),
			),
			"CreateUser": Endpoint(
				service_name="ServerRPC",
				name="CreateUser",
				function=getattr(service, "CreateUser"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.CreateUserRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.CreateUserResponse"),
			),
			"DeleteUser": Endpoint(
				service_name="ServerRPC",
				name="DeleteUser",
				function=getattr(service, "DeleteUser"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.DeleteUserRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.DeleteUserResponse"),
			),
			"ExportUser": Endpoint(
				service_name="ServerRPC",
				name="ExportUser",
				function=getattr(service, "ExportUser"),
				input=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.ExportUserRequest"),
				output=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.ExportUserResponse"),
			),
		}

class ServerRPCClient(TwirpClient):

	def GetApp(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/GetApp",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.GetAppResponse"),
			**kwargs,
		)

	def UpdateApp(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/UpdateApp",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.UpdateAppResponse"),
			**kwargs,
		)

	def CreateCallType(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/CreateCallType",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.CreateCallTypeResponse"),
			**kwargs,
		)

	def GetCallType(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/GetCallType",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.GetCallTypeResponse"),
			**kwargs,
		)

	def QueryCallTypes(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/QueryCallTypes",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.QueryCallTypesResponse"),
			**kwargs,
		)

	def UpdateCallType(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/UpdateCallType",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.UpdateCallTypeResponse"),
			**kwargs,
		)

	def DeleteCallType(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/DeleteCallType",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.DeleteCallTypeResponse"),
			**kwargs,
		)

	def CreatePushProvider(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/CreatePushProvider",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.CreatePushProviderResponse"),
			**kwargs,
		)

	def GetPushProvider(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/GetPushProvider",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.GetPushProviderResponse"),
			**kwargs,
		)

	def QueryPushProviders(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/QueryPushProviders",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.QueryPushProvidersResponse"),
			**kwargs,
		)

	def UpdatePushProvider(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/UpdatePushProvider",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.UpdatePushProviderResponse"),
			**kwargs,
		)

	def DeletePushProvider(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/DeletePushProvider",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.DeletePushProviderResponse"),
			**kwargs,
		)

	def StartBroadcast(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/StartBroadcast",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.StartBroadcastResponse"),
			**kwargs,
		)

	def StopBroadcast(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/StopBroadcast",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.StopBroadcastResponse"),
			**kwargs,
		)

	def StartRecording(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/StartRecording",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.StartRecordingResponse"),
			**kwargs,
		)

	def StopRecording(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/StopRecording",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.StopRecordingResponse"),
			**kwargs,
		)

	def GetRecordings(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/GetRecordings",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.GetRecordingsResponse"),
			**kwargs,
		)

	def DeleteRecording(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/DeleteRecording",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.DeleteRecordingResponse"),
			**kwargs,
		)

	def QueryCallTimelineEvents(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/QueryCallTimelineEvents",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.QueryCallTimelineEventsResponse"),
			**kwargs,
		)

	def CreateUser(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/CreateUser",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.CreateUserResponse"),
			**kwargs,
		)

	def DeleteUser(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/DeleteUser",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.DeleteUserResponse"),
			**kwargs,
		)

	def ExportUser(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.coordinator.server_v1_rpc.ServerRPC/ExportUser",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.coordinator.server_v1_rpc.ExportUserResponse"),
			**kwargs,
		)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Direction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DirectionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Direction.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DIRECTION_UNSPECIFIED: _Direction.ValueType  # 0
    DIRECTION_DESC: _Direction.ValueType  # -1
    DIRECTION_ASC: _Direction.ValueType  # 1

class Direction(_Direction, metaclass=_DirectionEnumTypeWrapper): ...

DIRECTION_UNSPECIFIED: Direction.ValueType  # 0
DIRECTION_DESC: Direction.ValueType  # -1
DIRECTION_ASC: Direction.ValueType  # 1
global___Direction = Direction

class Sort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    field: builtins.str
    direction: global___Direction.ValueType
    def __init__(
        self,
        *,
        field: builtins.str = ...,
        direction: global___Direction.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["direction", b"direction", "field", b"field"]) -> None: ...

global___Sort = Sort



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import video.coordinator.member_v1.member_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CallType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The unique name for the call type."""
    @property
    def options(self) -> global___CallOptions: ...
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        options: global___CallOptions | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "options", b"options", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "name", b"name", "options", b"options", "updated_at", b"updated_at"]) -> None: ...

global___CallType = CallType

class Call(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CALL_CID_FIELD_NUMBER: builtins.int
    CREATED_BY_USER_ID_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    type: builtins.str
    """The call type."""
    id: builtins.str
    """The call id."""
    call_cid: builtins.str
    """A concatenation of call type and call id with ":" inbetween"""
    created_by_user_id: builtins.str
    """The id of the user that created this room."""
    custom_json: builtins.bytes
    @property
    def options(self) -> global___CallOptions:
        """Room options that are set explicitly in this room
        This set of options does not include RoomType options
        """
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        id: builtins.str = ...,
        call_cid: builtins.str = ...,
        created_by_user_id: builtins.str = ...,
        custom_json: builtins.bytes = ...,
        options: global___CallOptions | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "options", b"options", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cid", b"call_cid", "created_at", b"created_at", "created_by_user_id", b"created_by_user_id", "custom_json", b"custom_json", "id", b"id", "options", b"options", "type", b"type", "updated_at", b"updated_at"]) -> None: ...

global___Call = Call

class CallDetails(google.protobuf.message.Message):
    """CallDetails contains call additional details"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class MembersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> video.coordinator.member_v1.member_pb2.Member: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: video.coordinator.member_v1.member_pb2.Member | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    MEMBER_USER_IDS_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___CallOptions:
        """Call options merged with CallType options"""
    @property
    def member_user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Ordered list of member user IDs"""
    @property
    def members(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, video.coordinator.member_v1.member_pb2.Member]:
        """Room members map indexed by Member.user_id
        Cannot have more than 100 members
        """
    def __init__(
        self,
        *,
        options: global___CallOptions | None = ...,
        member_user_ids: collections.abc.Iterable[builtins.str] | None = ...,
        members: collections.abc.Mapping[builtins.str, video.coordinator.member_v1.member_pb2.Member] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["member_user_ids", b"member_user_ids", "members", b"members", "options", b"options"]) -> None: ...

global___CallDetails = CallDetails

class CallOptions(google.protobuf.message.Message):
    """CallOptions contains all options available to change for the RoomType
    Options can also be set on the room level where they will be merged with RoomType options using `proto.Merge`
    To make sure options can be overriden on the room level, all underlying option fields should be optional
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORDING_FIELD_NUMBER: builtins.int
    BROADCASTING_FIELD_NUMBER: builtins.int
    @property
    def recording(self) -> global___RecordingOptions: ...
    @property
    def broadcasting(self) -> global___BroadcastingOptions: ...
    def __init__(
        self,
        *,
        recording: global___RecordingOptions | None = ...,
        broadcasting: global___BroadcastingOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["broadcasting", b"broadcasting", "recording", b"recording"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["broadcasting", b"broadcasting", "recording", b"recording"]) -> None: ...

global___CallOptions = CallOptions

class RecordingOptions(google.protobuf.message.Message):
    """Contains all options regarding to call recording"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    """Whether recording feature is enabled
    Default: false
    """
    def __init__(
        self,
        *,
        enabled: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_enabled", b"_enabled", "enabled", b"enabled"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_enabled", b"_enabled", "enabled", b"enabled"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_enabled", b"_enabled"]) -> typing_extensions.Literal["enabled"] | None: ...

global___RecordingOptions = RecordingOptions

class BroadcastingOptions(google.protobuf.message.Message):
    """Contains all options regarding to call broadcasting"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    """Whether broadcasting feature is enabled
    Default: false
    """
    def __init__(
        self,
        *,
        enabled: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_enabled", b"_enabled", "enabled", b"enabled"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_enabled", b"_enabled", "enabled", b"enabled"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_enabled", b"_enabled"]) -> typing_extensions.Literal["enabled"] | None: ...

global___BroadcastingOptions = BroadcastingOptions



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PushProvider(google.protobuf.message.Message):
    """Keep in sync with stream.config.push.PushProvider"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    DISABLED_REASON_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    APN_FIELD_NUMBER: builtins.int
    FIREBASE_FIELD_NUMBER: builtins.int
    HUAWEI_FIELD_NUMBER: builtins.int
    XIAOMI_FIELD_NUMBER: builtins.int
    id: builtins.str
    disabled: builtins.bool
    disabled_reason: builtins.str
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def apn(self) -> global___ApnCredentials: ...
    @property
    def firebase(self) -> global___FirebaseCredentials: ...
    @property
    def huawei(self) -> global___HuaweiCredentials: ...
    @property
    def xiaomi(self) -> global___XiaomiCredentials: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        disabled: builtins.bool = ...,
        disabled_reason: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        apn: global___ApnCredentials | None = ...,
        firebase: global___FirebaseCredentials | None = ...,
        huawei: global___HuaweiCredentials | None = ...,
        xiaomi: global___XiaomiCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["apn", b"apn", "created_at", b"created_at", "credentials", b"credentials", "firebase", b"firebase", "huawei", b"huawei", "updated_at", b"updated_at", "xiaomi", b"xiaomi"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apn", b"apn", "created_at", b"created_at", "credentials", b"credentials", "disabled", b"disabled", "disabled_reason", b"disabled_reason", "firebase", b"firebase", "huawei", b"huawei", "id", b"id", "updated_at", b"updated_at", "xiaomi", b"xiaomi"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["credentials", b"credentials"]) -> typing_extensions.Literal["apn", "firebase", "huawei", "xiaomi"] | None: ...

global___PushProvider = PushProvider

class ApnCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTH_KEY_FIELD_NUMBER: builtins.int
    KEY_ID_FIELD_NUMBER: builtins.int
    APN_TOPIC_FIELD_NUMBER: builtins.int
    TEAM_ID_FIELD_NUMBER: builtins.int
    DEVELOPMENT_FIELD_NUMBER: builtins.int
    auth_key: builtins.str
    key_id: builtins.str
    apn_topic: builtins.str
    team_id: builtins.str
    development: builtins.bool
    def __init__(
        self,
        *,
        auth_key: builtins.str = ...,
        key_id: builtins.str = ...,
        apn_topic: builtins.str = ...,
        team_id: builtins.str = ...,
        development: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["apn_topic", b"apn_topic", "auth_key", b"auth_key", "development", b"development", "key_id", b"key_id", "team_id", b"team_id"]) -> None: ...

global___ApnCredentials = ApnCredentials

class FirebaseCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_KEY_FIELD_NUMBER: builtins.int
    CREDENTIALS_JSON_FIELD_NUMBER: builtins.int
    server_key: builtins.str
    credentials_json: builtins.str
    def __init__(
        self,
        *,
        server_key: builtins.str = ...,
        credentials_json: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials_json", b"credentials_json", "server_key", b"server_key"]) -> None: ...

global___FirebaseCredentials = FirebaseCredentials

class HuaweiCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    id: builtins.str
    secret: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        secret: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "secret", b"secret"]) -> None: ...

global___HuaweiCredentials = HuaweiCredentials

class XiaomiCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    secret: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        secret: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["package_name", b"package_name", "secret", b"secret"]) -> None: ...

global___XiaomiCredentials = XiaomiCredentials

class Device(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    DISABLED_REASON_FIELD_NUMBER: builtins.int
    PUSH_PROVIDER_NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    id: builtins.str
    disabled: builtins.bool
    disabled_reason: builtins.str
    push_provider_name: builtins.str
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        id: builtins.str = ...,
        disabled: builtins.bool = ...,
        disabled_reason: builtins.str = ...,
        push_provider_name: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "disabled", b"disabled", "disabled_reason", b"disabled_reason", "id", b"id", "push_provider_name", b"push_provider_name", "updated_at", b"updated_at", "user_id", b"user_id"]) -> None: ...

global___Device = Device

class DeviceInput(google.protobuf.message.Message):
    """An object that is used in requests to create or update a device"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PUSH_PROVIDER_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique device ID, specific to a provider"""
    push_provider_id: builtins.str
    """Push provider ID, as configured in application push notification settings
    Refers to a set of credentials and templates of one of the supported push providers
    """
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        push_provider_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "push_provider_id", b"push_provider_id"]) -> None: ...

global___DeviceInput = DeviceInput



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/broadcast_v1/broadcast.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.video/coordinator/broadcast_v1/broadcast.proto\x12%stream.video.coordinator.broadcast_v1\"\x1b\n\x0bRTMPOptions\x12\x0c\n\x04urls\x18\x01 \x03(\t\"^\n\tBroadcast\x12@\n\x04rtmp\x18\x01 \x01(\x0b\x32\x32.stream.video.coordinator.broadcast_v1.RTMPOptions\x12\x0f\n\x07hls_url\x18\x02 \x01(\t*A\n\x05\x43odec\x12\x1a\n\x16\x43ODEC_H264_UNSPECIFIED\x10\x00\x12\r\n\tCODEC_VP8\x10\x01\x12\r\n\tCODEC_VP9\x10\x02\x42;B\x0b\x42roadcastV1P\x01Z\x0c\x62roadcast_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.broadcast_v1.broadcast_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\013BroadcastV1P\001Z\014broadcast_v1\252\002\033Stream.Video.v1.Coordinator'
  _CODEC._serialized_start=214
  _CODEC._serialized_end=279
  _RTMPOPTIONS._serialized_start=89
  _RTMPOPTIONS._serialized_end=116
  _BROADCAST._serialized_start=118
  _BROADCAST._serialized_end=212
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/utils_v1/utils.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&video/coordinator/utils_v1/utils.proto\x12!stream.video.coordinator.utils_v1\"V\n\x04Sort\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12?\n\tdirection\x18\x02 \x01(\x0e\x32,.stream.video.coordinator.utils_v1.Direction*V\n\tDirection\x12\x19\n\x15\x44IRECTION_UNSPECIFIED\x10\x00\x12\x1b\n\x0e\x44IRECTION_DESC\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x11\n\rDIRECTION_ASC\x10\x01\x42\x33\x42\x07UtilsV1P\x01Z\x08utils_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.utils_v1.utils_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\007UtilsV1P\001Z\010utils_v1\252\002\033Stream.Video.v1.Coordinator'
  _DIRECTION._serialized_start=165
  _DIRECTION._serialized_end=251
  _SORT._serialized_start=77
  _SORT._serialized_end=163
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/client_v1_rpc/websocket.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2
from video.coordinator.event_v1 import event_pb2 as video_dot_coordinator_dot_event__v1_dot_event__pb2
from video.coordinator.push_v1 import push_pb2 as video_dot_coordinator_dot_push__v1_dot_push__pb2
from video.coordinator.user_v1 import user_pb2 as video_dot_coordinator_dot_user__v1_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/video/coordinator/client_v1_rpc/websocket.proto\x12&stream.video.coordinator.client_v1_rpc\x1a\x17validate/validate.proto\x1a&video/coordinator/event_v1/event.proto\x1a$video/coordinator/push_v1/push.proto\x1a$video/coordinator/user_v1/user.proto\"\xa5\t\n\x0eWebsocketEvent\x12P\n\x05users\x18\x01 \x03(\x0b\x32\x41.stream.video.coordinator.client_v1_rpc.WebsocketEvent.UsersEntry\x12S\n\x0bhealthcheck\x18\x14 \x01(\x0b\x32<.stream.video.coordinator.client_v1_rpc.WebsocketHealthcheckH\x00\x12\x46\n\x0c\x63\x61ll_created\x18\x1e \x01(\x0b\x32..stream.video.coordinator.event_v1.CallCreatedH\x00\x12\x46\n\x0c\x63\x61ll_updated\x18\x1f \x01(\x0b\x32..stream.video.coordinator.event_v1.CallUpdatedH\x00\x12\x46\n\x0c\x63\x61ll_deleted\x18  \x01(\x0b\x32..stream.video.coordinator.event_v1.CallDeletedH\x00\x12U\n\x14\x63\x61ll_members_created\x18! \x01(\x0b\x32\x35.stream.video.coordinator.event_v1.CallMembersCreatedH\x00\x12U\n\x14\x63\x61ll_members_updated\x18\" \x01(\x0b\x32\x35.stream.video.coordinator.event_v1.CallMembersUpdatedH\x00\x12U\n\x14\x63\x61ll_members_deleted\x18# \x01(\x0b\x32\x35.stream.video.coordinator.event_v1.CallMembersDeletedH\x00\x12\x42\n\ncall_ended\x18$ \x01(\x0b\x32,.stream.video.coordinator.event_v1.CallEndedH\x00\x12H\n\rcall_accepted\x18( \x01(\x0b\x32/.stream.video.coordinator.event_v1.CallAcceptedH\x00\x12H\n\rcall_rejected\x18) \x01(\x0b\x32/.stream.video.coordinator.event_v1.CallRejectedH\x00\x12J\n\x0e\x63\x61ll_cancelled\x18* \x01(\x0b\x32\x30.stream.video.coordinator.event_v1.CallCancelledH\x00\x12\x46\n\x0cuser_updated\x18\x32 \x01(\x0b\x32..stream.video.coordinator.event_v1.UserUpdatedH\x00\x12\x44\n\x0b\x63\x61ll_custom\x18\x63 \x01(\x0b\x32-.stream.video.coordinator.event_v1.CallCustomH\x00\x1aT\n\nUsersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.stream.video.coordinator.user_v1.User:\x02\x38\x01\x42\x07\n\x05\x65vent\"\xca\x01\n\x14WebsocketClientEvent\x12S\n\x0bhealthcheck\x18\x01 \x01(\x0b\x32<.stream.video.coordinator.client_v1_rpc.WebsocketHealthcheckH\x00\x12T\n\x0c\x61uth_request\x18\x02 \x01(\x0b\x32<.stream.video.coordinator.client_v1_rpc.WebsocketAuthRequestH\x00\x42\x07\n\x05\x65vent\"\xb0\x01\n\x14WebsocketAuthRequest\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x39\n\x04user\x18\x03 \x01(\x0b\x32+.stream.video.coordinator.user_v1.UserInput\x12=\n\x06\x64\x65vice\x18\x04 \x01(\x0b\x32-.stream.video.coordinator.push_v1.DeviceInput\"\x8e\x01\n\x14WebsocketHealthcheck\x12\x18\n\x07user_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1a\n\tclient_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x11\n\tcall_type\x18\x03 \x01(\t\x12\x0f\n\x07\x63\x61ll_id\x18\x04 \x01(\t\x12\r\n\x05video\x18\x05 \x01(\x08\x12\r\n\x05\x61udio\x18\x06 \x01(\x08\x42@B\x11\x43lientV1WebsocketZ\rclient_v1_rpc\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.client_v1_rpc.websocket_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\021ClientV1WebsocketZ\rclient_v1_rpc\252\002\033Stream.Video.v1.Coordinator'
  _WEBSOCKETEVENT_USERSENTRY._options = None
  _WEBSOCKETEVENT_USERSENTRY._serialized_options = b'8\001'
  _WEBSOCKETHEALTHCHECK.fields_by_name['user_id']._options = None
  _WEBSOCKETHEALTHCHECK.fields_by_name['user_id']._serialized_options = b'\372B\004r\002\020\001'
  _WEBSOCKETHEALTHCHECK.fields_by_name['client_id']._options = None
  _WEBSOCKETHEALTHCHECK.fields_by_name['client_id']._serialized_options = b'\372B\004r\002\020\001'
  _WEBSOCKETEVENT._serialized_start=233
  _WEBSOCKETEVENT._serialized_end=1422
  _WEBSOCKETEVENT_USERSENTRY._serialized_start=1329
  _WEBSOCKETEVENT_USERSENTRY._serialized_end=1413
  _WEBSOCKETCLIENTEVENT._serialized_start=1425
  _WEBSOCKETCLIENTEVENT._serialized_end=1627
  _WEBSOCKETAUTHREQUEST._serialized_start=1630
  _WEBSOCKETAUTHREQUEST._serialized_end=1806
  _WEBSOCKETHEALTHCHECK._serialized_start=1809
  _WEBSOCKETHEALTHCHECK._serialized_end=1951
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateRoleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___CreateRoleRequest = CreateRoleRequest

class CreateRoleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_FIELD_NUMBER: builtins.int
    @property
    def role(self) -> global___Role: ...
    def __init__(
        self,
        *,
        role: global___Role | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["role", b"role"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["role", b"role"]) -> None: ...

global___CreateRoleResponse = CreateRoleResponse

class DeleteRoleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteRoleRequest = DeleteRoleRequest

class DeleteRoleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteRoleResponse = DeleteRoleResponse

class QueryRolesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryRolesRequest = QueryRolesRequest

class QueryRolesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLES_FIELD_NUMBER: builtins.int
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Role]: ...
    def __init__(
        self,
        *,
        roles: collections.abc.Iterable[global___Role] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["roles", b"roles"]) -> None: ...

global___QueryRolesResponse = QueryRolesResponse

class QueryActionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryActionsRequest = QueryActionsRequest

class QueryActionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_FIELD_NUMBER: builtins.int
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Action]: ...
    def __init__(
        self,
        *,
        actions: collections.abc.Iterable[global___Action] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions"]) -> None: ...

global___QueryActionsResponse = QueryActionsResponse

class QueryPermissionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryPermissionsRequest = QueryPermissionsRequest

class QueryPermissionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERMISSIONS_FIELD_NUMBER: builtins.int
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]: ...
    def __init__(
        self,
        *,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["permissions", b"permissions"]) -> None: ...

global___QueryPermissionsResponse = QueryPermissionsResponse

class UpdateScopeRequest(google.protobuf.message.Message):
    """A request message for UpdateScope endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class GrantsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Grants: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Grants | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    SCOPE_ID_FIELD_NUMBER: builtins.int
    GRANTS_FIELD_NUMBER: builtins.int
    scope_id: builtins.str
    """ID of the scope that is being updated"""
    @property
    def grants(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Grants]:
        """A list of grants to set
        To "delete" a role from the scope, empty list of permissions should be provided for such role
        """
    def __init__(
        self,
        *,
        scope_id: builtins.str = ...,
        grants: collections.abc.Mapping[builtins.str, global___Grants] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["grants", b"grants", "scope_id", b"scope_id"]) -> None: ...

global___UpdateScopeRequest = UpdateScopeRequest

class ResetScopeRequest(google.protobuf.message.Message):
    """A request message for ResetScope endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCOPE_ID_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    scope_id: builtins.str
    """ID of the scope that is being reset"""
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of roles to reset to defaults in the scope"""
    def __init__(
        self,
        *,
        scope_id: builtins.str = ...,
        roles: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["roles", b"roles", "scope_id", b"scope_id"]) -> None: ...

global___ResetScopeRequest = ResetScopeRequest

class ResetScopeResponse(google.protobuf.message.Message):
    """A response message for ResetScope endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCOPE_FIELD_NUMBER: builtins.int
    @property
    def scope(self) -> global___Scope:
        """An updated scope"""
    def __init__(
        self,
        *,
        scope: global___Scope | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["scope", b"scope"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["scope", b"scope"]) -> None: ...

global___ResetScopeResponse = ResetScopeResponse

class UpdateScopeResponse(google.protobuf.message.Message):
    """A response message for UpdateScope endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCOPE_FIELD_NUMBER: builtins.int
    @property
    def scope(self) -> global___Scope:
        """An updated scope"""
    def __init__(
        self,
        *,
        scope: global___Scope | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["scope", b"scope"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["scope", b"scope"]) -> None: ...

global___UpdateScopeResponse = UpdateScopeResponse

class QueryScopesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryScopesRequest = QueryScopesRequest

class QueryScopesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ScopesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Scope: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Scope | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    SCOPES_FIELD_NUMBER: builtins.int
    @property
    def scopes(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Scope]: ...
    def __init__(
        self,
        *,
        scopes: collections.abc.Mapping[builtins.str, global___Scope] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["scopes", b"scopes"]) -> None: ...

global___QueryScopesResponse = QueryScopesResponse

class Action(google.protobuf.message.Message):
    """Action is an action that is possible to grant to a user"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """A unique name of action"""
    description: builtins.str
    """Human-readable description, provided by Stream"""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of tags associated with action"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "tags", b"tags"]) -> None: ...

global___Action = Action

class Permission(google.protobuf.message.Message):
    """Permission defines a way to allow someone to perform an action
    Permission always governs one Action, and the set of actions is predefined by the product
    Also, Permission contains a condition which defines whether this permission applies to authorized user.
    There are builtin permissions that are provided by Stream with default permission settings. Builtin permissions cannot be deleted.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    SIMPLE_FIELD_NUMBER: builtins.int
    CUSTOM_MQ_FIELD_NUMBER: builtins.int
    id: builtins.str
    """A unique permission ID"""
    name: builtins.str
    """Human readable permission name"""
    description: builtins.str
    """Human readable permission description"""
    action: builtins.str
    """Action name that this permission applies to"""
    @property
    def simple(self) -> global___SimpleCondition:
        """Simple condition based on resource ownership and user team"""
    custom_mq: builtins.bytes
    """JSON object containing custom MQ condition. When condition is evaluted to `true`, the permission is granted"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        action: builtins.str = ...,
        simple: global___SimpleCondition | None = ...,
        custom_mq: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "custom_mq", b"custom_mq", "simple", b"simple"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "condition", b"condition", "custom_mq", b"custom_mq", "description", b"description", "id", b"id", "name", b"name", "simple", b"simple"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["condition", b"condition"]) -> typing_extensions.Literal["simple", "custom_mq"] | None: ...

global___Permission = Permission

class SimpleCondition(google.protobuf.message.Message):
    """A message containing simple permission condition"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    SAME_TEAM_FIELD_NUMBER: builtins.int
    owner: builtins.bool
    """When set to true, a permission is only granted when authorized user owns the resource that it acts on"""
    same_team: builtins.bool
    """When set to true, a permission is only granted when authorized user interacts with a resource from the same team"""
    def __init__(
        self,
        *,
        owner: builtins.bool = ...,
        same_team: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["owner", b"owner", "same_team", b"same_team"]) -> None: ...

global___SimpleCondition = SimpleCondition

class Role(google.protobuf.message.Message):
    """Role is a role of an application user
    It can be assigned to a User itself or on a more granular level (channel member in chat or room member in video)
    There are builtin roles that are provided by Stream with default permission settings. Builtin roles cannot be deleted.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Role name"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Role creation date"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "name", b"name"]) -> None: ...

global___Role = Role

class Scope(google.protobuf.message.Message):
    """Scope is a top-level permission group which governs all resources in it
    In chat, scope is a Channel Type. In video - Room Type
    There is also special `.app` scope which governs all resources that cannot be assigned to any scope (e.g. users)
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class GrantsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Grants: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Grants | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    GRANTS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique scope ID"""
    description: builtins.str
    """Human readable scope description, provided by Stream"""
    @property
    def grants(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Grants]:
        """A list of roles and their permissions in this scope
        If a role does not have any permissions, it will not be present in this list
        """
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        description: builtins.str = ...,
        grants: collections.abc.Mapping[builtins.str, global___Grants] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "grants", b"grants", "id", b"id"]) -> None: ...

global___Scope = Scope

class Grants(google.protobuf.message.Message):
    """Grants is set of permissions that belong to a particular role"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    role: builtins.str
    """Role name that these grants apply to"""
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of Permission IDs"""
    def __init__(
        self,
        *,
        role: builtins.str = ...,
        permissions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["permissions", b"permissions", "role", b"role"]) -> None: ...

global___Grants = Grants



# -*- coding: utf-8 -*-
# Generated by https://github.com/verloop/twirpy/protoc-gen-twirpy.  DO NOT EDIT!
# source: video/sfu/cascading_rpc/gossip.proto

from google.protobuf import symbol_database as _symbol_database

from twirp.base import Endpoint
from twirp.server import TwirpServer
from twirp.client import TwirpClient

_sym_db = _symbol_database.Default()

class GossipRPCServer(TwirpServer):

	def __init__(self, *args, service, server_path_prefix="/twirp"):
		super().__init__(service=service)
		self._prefix = F"{server_path_prefix}/stream.video.sfu.gossip.GossipRPC"
		self._endpoints = {
			"JoinCall": Endpoint(
				service_name="GossipRPC",
				name="JoinCall",
				function=getattr(service, "JoinCall"),
				input=_sym_db.GetSymbol("stream.video.sfu.gossip.JoinCallRequest"),
				output=_sym_db.GetSymbol("stream.video.sfu.gossip.JoinCallResponse"),
			),
			"SendEvent": Endpoint(
				service_name="GossipRPC",
				name="SendEvent",
				function=getattr(service, "SendEvent"),
				input=_sym_db.GetSymbol("stream.video.sfu.gossip.SendEventRequest"),
				output=_sym_db.GetSymbol("stream.video.sfu.gossip.SendEventResponse"),
			),
			"GetCallState": Endpoint(
				service_name="GossipRPC",
				name="GetCallState",
				function=getattr(service, "GetCallState"),
				input=_sym_db.GetSymbol("stream.video.sfu.gossip.GetCallStateRequest"),
				output=_sym_db.GetSymbol("stream.video.sfu.gossip.GetCallStateResponse"),
			),
		}

class GossipRPCClient(TwirpClient):

	def JoinCall(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.sfu.gossip.GossipRPC/JoinCall",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.sfu.gossip.JoinCallResponse"),
			**kwargs,
		)

	def SendEvent(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.sfu.gossip.GossipRPC/SendEvent",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.sfu.gossip.SendEventResponse"),
			**kwargs,
		)

	def GetCallState(self, *args, ctx, request, server_path_prefix="/twirp", **kwargs):
		return self._make_request(
			url=F"{server_path_prefix}/stream.video.sfu.gossip.GossipRPC/GetCallState",
			ctx=ctx,
			request=request,
			response_obj=_sym_db.GetSymbol("stream.video.sfu.gossip.GetCallStateResponse"),
			**kwargs,
		)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/server_v1_rpc/envelopes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video.coordinator.call_v1 import call_pb2 as video_dot_coordinator_dot_call__v1_dot_call__pb2
from video.coordinator.member_v1 import member_pb2 as video_dot_coordinator_dot_member__v1_dot_member__pb2
from video.coordinator.recording_v1 import recording_pb2 as video_dot_coordinator_dot_recording__v1_dot_recording__pb2
from video.coordinator.user_v1 import user_pb2 as video_dot_coordinator_dot_user__v1_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/video/coordinator/server_v1_rpc/envelopes.proto\x12&stream.video.coordinator.server_v1_rpc\x1a$video/coordinator/call_v1/call.proto\x1a(video/coordinator/member_v1/member.proto\x1a.video/coordinator/recording_v1/recording.proto\x1a$video/coordinator/user_v1/user.proto\"\xfd\x02\n\x12\x45xportUserEnvelope\x12\x34\n\x04user\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.user_v1.User\x12\x35\n\x05\x63\x61lls\x18\x02 \x03(\x0b\x32&.stream.video.coordinator.call_v1.Call\x12X\n\x07members\x18\x03 \x03(\x0b\x32G.stream.video.coordinator.server_v1_rpc.ExportUserEnvelope.MembersEntry\x12\x44\n\nrecordings\x18\x04 \x03(\x0b\x32\x30.stream.video.coordinator.recording_v1.Recording\x1aZ\n\x0cMembersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.stream.video.coordinator.member_v1.Member:\x02\x38\x01\x42\x0fZ\rserver_v1_rpcb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.server_v1_rpc.envelopes_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\rserver_v1_rpc'
  _EXPORTUSERENVELOPE_MEMBERSENTRY._options = None
  _EXPORTUSERENVELOPE_MEMBERSENTRY._serialized_options = b'8\001'
  _EXPORTUSERENVELOPE._serialized_start=258
  _EXPORTUSERENVELOPE._serialized_end=639
  _EXPORTUSERENVELOPE_MEMBERSENTRY._serialized_start=549
  _EXPORTUSERENVELOPE_MEMBERSENTRY._serialized_end=639
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MediaType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MediaTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MediaType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MEDIA_TYPE_UNSPECIFIED: _MediaType.ValueType  # 0
    MEDIA_TYPE_AUDIO: _MediaType.ValueType  # 1
    MEDIA_TYPE_VIDEO: _MediaType.ValueType  # 2

class MediaType(_MediaType, metaclass=_MediaTypeEnumTypeWrapper): ...

MEDIA_TYPE_UNSPECIFIED: MediaType.ValueType  # 0
MEDIA_TYPE_AUDIO: MediaType.ValueType  # 1
MEDIA_TYPE_VIDEO: MediaType.ValueType  # 2
global___MediaType = MediaType

class _MediaStateChange:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MediaStateChangeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MediaStateChange.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MEDIA_STATE_CHANGE_UNSPECIFIED: _MediaStateChange.ValueType  # 0
    MEDIA_STATE_CHANGE_STARTED: _MediaStateChange.ValueType  # 1
    MEDIA_STATE_CHANGE_ENDED: _MediaStateChange.ValueType  # 2

class MediaStateChange(_MediaStateChange, metaclass=_MediaStateChangeEnumTypeWrapper): ...

MEDIA_STATE_CHANGE_UNSPECIFIED: MediaStateChange.ValueType  # 0
MEDIA_STATE_CHANGE_STARTED: MediaStateChange.ValueType  # 1
MEDIA_STATE_CHANGE_ENDED: MediaStateChange.ValueType  # 2
global___MediaStateChange = MediaStateChange

class _MediaDirection:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MediaDirectionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MediaDirection.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MEDIA_DIRECTION_UNSPECIFIED: _MediaDirection.ValueType  # 0
    MEDIA_DIRECTION_SEND: _MediaDirection.ValueType  # 1
    MEDIA_DIRECTION_RECEIVE: _MediaDirection.ValueType  # 2

class MediaDirection(_MediaDirection, metaclass=_MediaDirectionEnumTypeWrapper): ...

MEDIA_DIRECTION_UNSPECIFIED: MediaDirection.ValueType  # 0
MEDIA_DIRECTION_SEND: MediaDirection.ValueType  # 1
MEDIA_DIRECTION_RECEIVE: MediaDirection.ValueType  # 2
global___MediaDirection = MediaDirection

class _MediaStateChangeReason:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MediaStateChangeReasonEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MediaStateChangeReason.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MEDIA_STATE_CHANGE_REASON_UNSPECIFIED: _MediaStateChangeReason.ValueType  # 0
    MEDIA_STATE_CHANGE_REASON_MUTE: _MediaStateChangeReason.ValueType  # 1
    MEDIA_STATE_CHANGE_REASON_CONNECTION: _MediaStateChangeReason.ValueType  # 2

class MediaStateChangeReason(_MediaStateChangeReason, metaclass=_MediaStateChangeReasonEnumTypeWrapper): ...

MEDIA_STATE_CHANGE_REASON_UNSPECIFIED: MediaStateChangeReason.ValueType  # 0
MEDIA_STATE_CHANGE_REASON_MUTE: MediaStateChangeReason.ValueType  # 1
MEDIA_STATE_CHANGE_REASON_CONNECTION: MediaStateChangeReason.ValueType  # 2
global___MediaStateChangeReason = MediaStateChangeReason

class ParticipantConnected(google.protobuf.message.Message):
    """ParticipantConnected is fired when a user joins a call"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ParticipantConnected = ParticipantConnected

class ParticipantDisconnected(google.protobuf.message.Message):
    """ParticipantDisconnected is fired when a user leaves a call"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ParticipantDisconnected = ParticipantDisconnected

class Freeze(google.protobuf.message.Message):
    """The participant experienced a significant amount of audio/video freeze when observing a given peer"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIA_TYPE_FIELD_NUMBER: builtins.int
    PEER_ID_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    media_type: global___MediaType.ValueType
    peer_id: builtins.str
    """Sender of the media stream"""
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        media_type: global___MediaType.ValueType = ...,
        peer_id: builtins.str = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "media_type", b"media_type", "peer_id", b"peer_id"]) -> None: ...

global___Freeze = Freeze

class MediaStateChanged(google.protobuf.message.Message):
    """A participant started/ended sending/receiving audio/video for a given reason"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIA_TYPE_FIELD_NUMBER: builtins.int
    CHANGE_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    media_type: global___MediaType.ValueType
    change: global___MediaStateChange.ValueType
    direction: global___MediaDirection.ValueType
    reason: global___MediaStateChangeReason.ValueType
    def __init__(
        self,
        *,
        media_type: global___MediaType.ValueType = ...,
        change: global___MediaStateChange.ValueType = ...,
        direction: global___MediaDirection.ValueType = ...,
        reason: global___MediaStateChangeReason.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["change", b"change", "direction", b"direction", "media_type", b"media_type", "reason", b"reason"]) -> None: ...

global___MediaStateChanged = MediaStateChanged

class TelemetryEvent(google.protobuf.message.Message):
    """A stat event from the perspective of a particular participant"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    PARTICIPANT_CONNECTED_FIELD_NUMBER: builtins.int
    PARTICIPANT_DISCONNECTED_FIELD_NUMBER: builtins.int
    MEDIA_STATE_CHANGED_FIELD_NUMBER: builtins.int
    FREEZE_FIELD_NUMBER: builtins.int
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Event timestamp as RFC3339 string."""
    @property
    def participant_connected(self) -> global___ParticipantConnected: ...
    @property
    def participant_disconnected(self) -> global___ParticipantDisconnected: ...
    @property
    def media_state_changed(self) -> global___MediaStateChanged: ...
    @property
    def freeze(self) -> global___Freeze: ...
    def __init__(
        self,
        *,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        participant_connected: global___ParticipantConnected | None = ...,
        participant_disconnected: global___ParticipantDisconnected | None = ...,
        media_state_changed: global___MediaStateChanged | None = ...,
        freeze: global___Freeze | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event", b"event", "freeze", b"freeze", "media_state_changed", b"media_state_changed", "participant_connected", b"participant_connected", "participant_disconnected", b"participant_disconnected", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event", b"event", "freeze", b"freeze", "media_state_changed", b"media_state_changed", "participant_connected", b"participant_connected", "participant_disconnected", b"participant_disconnected", "timestamp", b"timestamp"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event", b"event"]) -> typing_extensions.Literal["participant_connected", "participant_disconnected", "media_state_changed", "freeze"] | None: ...

global___TelemetryEvent = TelemetryEvent

class CallParticipantTimeline(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """The events in this timeline are from the perspective of the user with this ID"""
    session_id: builtins.str
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TelemetryEvent]: ...
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        session_id: builtins.str = ...,
        events: collections.abc.Iterable[global___TelemetryEvent] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["events", b"events", "session_id", b"session_id", "user_id", b"user_id"]) -> None: ...

global___CallParticipantTimeline = CallParticipantTimeline



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/client_v1_rpc/envelopes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video.coordinator.call_v1 import call_pb2 as video_dot_coordinator_dot_call__v1_dot_call__pb2
from video.coordinator.member_v1 import member_pb2 as video_dot_coordinator_dot_member__v1_dot_member__pb2
from video.coordinator.user_v1 import user_pb2 as video_dot_coordinator_dot_user__v1_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/video/coordinator/client_v1_rpc/envelopes.proto\x12&stream.video.coordinator.client_v1_rpc\x1a$video/coordinator/call_v1/call.proto\x1a(video/coordinator/member_v1/member.proto\x1a$video/coordinator/user_v1/user.proto\"\xaa\x02\n\x0c\x43\x61llEnvelope\x12N\n\x05users\x18\x01 \x03(\x0b\x32?.stream.video.coordinator.client_v1_rpc.CallEnvelope.UsersEntry\x12\x34\n\x04\x63\x61ll\x18\x02 \x01(\x0b\x32&.stream.video.coordinator.call_v1.Call\x12>\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetails\x1aT\n\nUsersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.stream.video.coordinator.user_v1.User:\x02\x38\x01\"\xa4\x04\n\rCallsEnvelope\x12O\n\x05users\x18\x01 \x03(\x0b\x32@.stream.video.coordinator.client_v1_rpc.CallsEnvelope.UsersEntry\x12\x11\n\tcall_cids\x18\x02 \x03(\t\x12O\n\x05\x63\x61lls\x18\x03 \x03(\x0b\x32@.stream.video.coordinator.client_v1_rpc.CallsEnvelope.CallsEntry\x12S\n\x07\x64\x65tails\x18\x04 \x03(\x0b\x32\x42.stream.video.coordinator.client_v1_rpc.CallsEnvelope.DetailsEntry\x1aT\n\nUsersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.stream.video.coordinator.user_v1.User:\x02\x38\x01\x1aT\n\nCallsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.stream.video.coordinator.call_v1.Call:\x02\x38\x01\x1a]\n\x0c\x44\x65tailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12<\n\x05value\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetails:\x02\x38\x01\"\x86\x03\n\x0fMembersEnvelope\x12Q\n\x05users\x18\x01 \x03(\x0b\x32\x42.stream.video.coordinator.client_v1_rpc.MembersEnvelope.UsersEntry\x12\x17\n\x0fmember_user_ids\x18\x02 \x03(\t\x12U\n\x07members\x18\x03 \x03(\x0b\x32\x44.stream.video.coordinator.client_v1_rpc.MembersEnvelope.MembersEntry\x1aT\n\nUsersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.stream.video.coordinator.user_v1.User:\x02\x38\x01\x1aZ\n\x0cMembersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.stream.video.coordinator.member_v1.Member:\x02\x38\x01\x42@B\x11\x43lientV1EnvelopesZ\rclient_v1_rpc\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.client_v1_rpc.envelopes_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\021ClientV1EnvelopesZ\rclient_v1_rpc\252\002\033Stream.Video.v1.Coordinator'
  _CALLENVELOPE_USERSENTRY._options = None
  _CALLENVELOPE_USERSENTRY._serialized_options = b'8\001'
  _CALLSENVELOPE_USERSENTRY._options = None
  _CALLSENVELOPE_USERSENTRY._serialized_options = b'8\001'
  _CALLSENVELOPE_CALLSENTRY._options = None
  _CALLSENVELOPE_CALLSENTRY._serialized_options = b'8\001'
  _CALLSENVELOPE_DETAILSENTRY._options = None
  _CALLSENVELOPE_DETAILSENTRY._serialized_options = b'8\001'
  _MEMBERSENVELOPE_USERSENTRY._options = None
  _MEMBERSENVELOPE_USERSENTRY._serialized_options = b'8\001'
  _MEMBERSENVELOPE_MEMBERSENTRY._options = None
  _MEMBERSENVELOPE_MEMBERSENTRY._serialized_options = b'8\001'
  _CALLENVELOPE._serialized_start=210
  _CALLENVELOPE._serialized_end=508
  _CALLENVELOPE_USERSENTRY._serialized_start=424
  _CALLENVELOPE_USERSENTRY._serialized_end=508
  _CALLSENVELOPE._serialized_start=511
  _CALLSENVELOPE._serialized_end=1059
  _CALLSENVELOPE_USERSENTRY._serialized_start=424
  _CALLSENVELOPE_USERSENTRY._serialized_end=508
  _CALLSENVELOPE_CALLSENTRY._serialized_start=880
  _CALLSENVELOPE_CALLSENTRY._serialized_end=964
  _CALLSENVELOPE_DETAILSENTRY._serialized_start=966
  _CALLSENVELOPE_DETAILSENTRY._serialized_end=1059
  _MEMBERSENVELOPE._serialized_start=1062
  _MEMBERSENVELOPE._serialized_end=1452
  _MEMBERSENVELOPE_USERSENTRY._serialized_start=424
  _MEMBERSENVELOPE_USERSENTRY._serialized_end=508
  _MEMBERSENVELOPE_MEMBERSENTRY._serialized_start=1362
  _MEMBERSENVELOPE_MEMBERSENTRY._serialized_end=1452
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class User(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TEAMS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def teams(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    custom_json: builtins.bytes
    name: builtins.str
    image_url: builtins.str
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """User creation date"""
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """User last update date."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        teams: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        custom_json: builtins.bytes = ...,
        name: builtins.str = ...,
        image_url: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "custom_json", b"custom_json", "id", b"id", "image_url", b"image_url", "name", b"name", "role", b"role", "teams", b"teams", "updated_at", b"updated_at"]) -> None: ...

global___User = User

class UserInput(google.protobuf.message.Message):
    """A message that is used in User requests to create and modify user data"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TEAMS_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    name: builtins.str
    """A human-readable name of the user"""
    role: builtins.str
    """User role, as defined by permission settings"""
    @property
    def teams(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of user teams for multi-tenant applications"""
    image_url: builtins.str
    """A URL that points to a user image"""
    custom_json: builtins.bytes
    """A JSON object with custom user information"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        role: builtins.str = ...,
        teams: collections.abc.Iterable[builtins.str] | None = ...,
        image_url: builtins.str = ...,
        custom_json: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_json", b"custom_json", "image_url", b"image_url", "name", b"name", "role", b"role", "teams", b"teams"]) -> None: ...

global___UserInput = UserInput



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/recording_v1/recording.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.video/coordinator/recording_v1/recording.proto\x12%stream.video.coordinator.recording_v1\"k\n\tRecording\x12\x11\n\tcall_type\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61ll_id\x18\x02 \x01(\t\x12\x13\n\x0bs3_file_url\x18\x03 \x01(\t\x12\x12\n\nstart_time\x18\x04 \x01(\t\x12\x11\n\tstop_time\x18\x05 \x01(\t\"E\n\x04\x46ile\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x11\n\tcomposite\x18\x02 \x01(\x08\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\"`\n\x0fRecordBroadcast\x12\x11\n\tcomposite\x18\x01 \x01(\x08\x12:\n\x05\x66iles\x18\x02 \x03(\x0b\x32+.stream.video.coordinator.recording_v1.File\"\xbe\x01\n\x17RecordingStorageOptions\x12H\n\x07storage\x18\x01 \x01(\x0e\x32\x37.stream.video.coordinator.recording_v1.RecordingStorage\x12\x12\n\naccess_key\x18\x02 \x01(\t\x12\x12\n\nsecret_key\x18\x03 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x0c\n\x04path\x18\x06 \x01(\t*8\n\x10RecordingStorage\x12$\n RECORDING_STORAGE_S3_UNSPECIFIED\x10\x00\x42;B\x0bRecordingV1P\x01Z\x0crecording_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.recording_v1.recording_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\013RecordingV1P\001Z\014recording_v1\252\002\033Stream.Video.v1.Coordinator'
  _RECORDINGSTORAGE._serialized_start=560
  _RECORDINGSTORAGE._serialized_end=616
  _RECORDING._serialized_start=89
  _RECORDING._serialized_end=196
  _FILE._serialized_start=198
  _FILE._serialized_end=267
  _RECORDBROADCAST._serialized_start=269
  _RECORDBROADCAST._serialized_end=365
  _RECORDINGSTORAGEOPTIONS._serialized_start=368
  _RECORDINGSTORAGEOPTIONS._serialized_end=558
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import video.coordinator.call_v1.call_pb2
import video.coordinator.client_v1_rpc.envelopes_pb2
import video.coordinator.edge_v1.edge_pb2
import video.coordinator.push_v1.push_pb2
import video.coordinator.stat_v1.stat_pb2
import video.coordinator.utils_v1.utils_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _UserEventType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UserEventTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UserEventType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    USER_EVENT_TYPE_UNSPECIFIED: _UserEventType.ValueType  # 0
    USER_EVENT_TYPE_ACCEPTED_CALL: _UserEventType.ValueType  # 1
    USER_EVENT_TYPE_REJECTED_CALL: _UserEventType.ValueType  # 2
    USER_EVENT_TYPE_CANCELLED_CALL: _UserEventType.ValueType  # 3

class UserEventType(_UserEventType, metaclass=_UserEventTypeEnumTypeWrapper): ...

USER_EVENT_TYPE_UNSPECIFIED: UserEventType.ValueType  # 0
USER_EVENT_TYPE_ACCEPTED_CALL: UserEventType.ValueType  # 1
USER_EVENT_TYPE_REJECTED_CALL: UserEventType.ValueType  # 2
USER_EVENT_TYPE_CANCELLED_CALL: UserEventType.ValueType  # 3
global___UserEventType = UserEventType

class GetCallRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_CID_FIELD_NUMBER: builtins.int
    call_cid: builtins.str
    def __init__(
        self,
        *,
        call_cid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cid", b"call_cid"]) -> None: ...

global___GetCallRequest = GetCallRequest

class GetCallResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.client_v1_rpc.envelopes_pb2.CallEnvelope: ...
    def __init__(
        self,
        *,
        call: video.coordinator.client_v1_rpc.envelopes_pb2.CallEnvelope | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call"]) -> None: ...

global___GetCallResponse = GetCallResponse

class MemberInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    role: builtins.str
    custom_json: builtins.bytes
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        role: builtins.str = ...,
        custom_json: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_json", b"custom_json", "role", b"role", "user_id", b"user_id"]) -> None: ...

global___MemberInput = MemberInput

class UpsertCallMembersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_CID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    RING_FIELD_NUMBER: builtins.int
    call_cid: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MemberInput]: ...
    ring: builtins.bool
    """Ringing option, used to signal to clients' UI"""
    def __init__(
        self,
        *,
        call_cid: builtins.str = ...,
        members: collections.abc.Iterable[global___MemberInput] | None = ...,
        ring: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cid", b"call_cid", "members", b"members", "ring", b"ring"]) -> None: ...

global___UpsertCallMembersRequest = UpsertCallMembersRequest

class UpsertCallMembersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpsertCallMembersResponse = UpsertCallMembersResponse

class DeleteCallMembersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_CID_FIELD_NUMBER: builtins.int
    USER_IDS_FIELD_NUMBER: builtins.int
    call_cid: builtins.str
    @property
    def user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        call_cid: builtins.str = ...,
        user_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cid", b"call_cid", "user_ids", b"user_ids"]) -> None: ...

global___DeleteCallMembersRequest = DeleteCallMembersRequest

class DeleteCallMembersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteCallMembersResponse = DeleteCallMembersResponse

class CreateCallInput(google.protobuf.message.Message):
    """A message that carries data for call creation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    RING_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> global___CallInput:
        """Call properties to set"""
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MemberInput]:
        """Members to add to the created call"""
    ring: builtins.bool
    """Ringing option, used to signal to clients' UI"""
    def __init__(
        self,
        *,
        call: global___CallInput | None = ...,
        members: collections.abc.Iterable[global___MemberInput] | None = ...,
        ring: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_ring", b"_ring", "call", b"call", "ring", b"ring"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_ring", b"_ring", "call", b"call", "members", b"members", "ring", b"ring"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_ring", b"_ring"]) -> typing_extensions.Literal["ring"] | None: ...

global___CreateCallInput = CreateCallInput

class CreateCallRequest(google.protobuf.message.Message):
    """A request message for GetOrCreateCall endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    type: builtins.str
    """Call type"""
    id: builtins.str
    """Call ID. If empty, will be generated as UUIDv4"""
    @property
    def input(self) -> global___CreateCallInput:
        """Call creation input, only used if the call does not exist"""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        id: builtins.str | None = ...,
        input: global___CreateCallInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_id", b"_id", "id", b"id", "input", b"input"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_id", b"_id", "id", b"id", "input", b"input", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_id", b"_id"]) -> typing_extensions.Literal["id"] | None: ...

global___CreateCallRequest = CreateCallRequest

class GetOrCreateCallRequest(google.protobuf.message.Message):
    """A request message for GetOrCreateCall endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    type: builtins.str
    """Call type"""
    id: builtins.str
    """Call ID"""
    @property
    def input(self) -> global___CreateCallInput:
        """Call creation input, only used if the call does not exist"""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        id: builtins.str = ...,
        input: global___CreateCallInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["input", b"input"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "input", b"input", "type", b"type"]) -> None: ...

global___GetOrCreateCallRequest = GetOrCreateCallRequest

class JoinCallRequest(google.protobuf.message.Message):
    """A request message for JoinCall endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    DATACENTER_ID_FIELD_NUMBER: builtins.int
    type: builtins.str
    """Call type"""
    id: builtins.str
    """Call ID"""
    @property
    def input(self) -> global___CreateCallInput:
        """Call creation input, only used if the call does not exist"""
    datacenter_id: builtins.str
    """Preferred client datacenter. This is optional and when set, preferred datacenter selection is not guaranteed"""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        id: builtins.str = ...,
        input: global___CreateCallInput | None = ...,
        datacenter_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["input", b"input"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["datacenter_id", b"datacenter_id", "id", b"id", "input", b"input", "type", b"type"]) -> None: ...

global___JoinCallRequest = JoinCallRequest

class JoinCallResponse(google.protobuf.message.Message):
    """A request message for GetOrCreateCall endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    EDGES_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.client_v1_rpc.envelopes_pb2.CallEnvelope: ...
    created: builtins.bool
    """Whether a call was created"""
    @property
    def edges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.coordinator.edge_v1.edge_pb2.Edge]:
        """A list of endpoints to measure latency"""
    def __init__(
        self,
        *,
        call: video.coordinator.client_v1_rpc.envelopes_pb2.CallEnvelope | None = ...,
        created: builtins.bool = ...,
        edges: collections.abc.Iterable[video.coordinator.edge_v1.edge_pb2.Edge] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "created", b"created", "edges", b"edges"]) -> None: ...

global___JoinCallResponse = JoinCallResponse

class CallInput(google.protobuf.message.Message):
    """Represents all updatable room fields"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    custom_json: builtins.bytes
    """Custom JSON object that is stored in this call
    All users with read permissions will have access to this object
    """
    @property
    def options(self) -> video.coordinator.call_v1.call_pb2.CallOptions:
        """Call options to set"""
    def __init__(
        self,
        *,
        custom_json: builtins.bytes = ...,
        options: video.coordinator.call_v1.call_pb2.CallOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_json", b"custom_json", "options", b"options"]) -> None: ...

global___CallInput = CallInput

class GetOrCreateCallResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.client_v1_rpc.envelopes_pb2.CallEnvelope: ...
    created: builtins.bool
    """Whether a call was created"""
    def __init__(
        self,
        *,
        call: video.coordinator.client_v1_rpc.envelopes_pb2.CallEnvelope | None = ...,
        created: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "created", b"created"]) -> None: ...

global___GetOrCreateCallResponse = GetOrCreateCallResponse

class UpdateCallRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_CID_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    call_cid: builtins.str
    @property
    def input(self) -> global___CallInput: ...
    def __init__(
        self,
        *,
        call_cid: builtins.str = ...,
        input: global___CallInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["input", b"input"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cid", b"call_cid", "input", b"input"]) -> None: ...

global___UpdateCallRequest = UpdateCallRequest

class UpdateCallResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.client_v1_rpc.envelopes_pb2.CallEnvelope: ...
    def __init__(
        self,
        *,
        call: video.coordinator.client_v1_rpc.envelopes_pb2.CallEnvelope | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call"]) -> None: ...

global___UpdateCallResponse = UpdateCallResponse

class CreateCallResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.client_v1_rpc.envelopes_pb2.CallEnvelope: ...
    def __init__(
        self,
        *,
        call: video.coordinator.client_v1_rpc.envelopes_pb2.CallEnvelope | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call"]) -> None: ...

global___CreateCallResponse = CreateCallResponse

class QueryCallsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MQ_JSON_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    SORTS_FIELD_NUMBER: builtins.int
    mq_json: builtins.bytes
    limit: builtins.int
    @property
    def sorts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.coordinator.utils_v1.utils_pb2.Sort]: ...
    def __init__(
        self,
        *,
        mq_json: builtins.bytes = ...,
        limit: builtins.int | None = ...,
        sorts: collections.abc.Iterable[video.coordinator.utils_v1.utils_pb2.Sort] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_limit", b"_limit", "limit", b"limit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_limit", b"_limit", "limit", b"limit", "mq_json", b"mq_json", "sorts", b"sorts"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_limit", b"_limit"]) -> typing_extensions.Literal["limit"] | None: ...

global___QueryCallsRequest = QueryCallsRequest

class QueryCallsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALLS_FIELD_NUMBER: builtins.int
    @property
    def calls(self) -> video.coordinator.client_v1_rpc.envelopes_pb2.CallsEnvelope: ...
    def __init__(
        self,
        *,
        calls: video.coordinator.client_v1_rpc.envelopes_pb2.CallsEnvelope | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["calls", b"calls"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["calls", b"calls"]) -> None: ...

global___QueryCallsResponse = QueryCallsResponse

class QueryMembersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MQ_JSON_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    SORTS_FIELD_NUMBER: builtins.int
    mq_json: builtins.bytes
    limit: builtins.int
    @property
    def sorts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.coordinator.utils_v1.utils_pb2.Sort]: ...
    def __init__(
        self,
        *,
        mq_json: builtins.bytes = ...,
        limit: builtins.int | None = ...,
        sorts: collections.abc.Iterable[video.coordinator.utils_v1.utils_pb2.Sort] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_limit", b"_limit", "limit", b"limit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_limit", b"_limit", "limit", b"limit", "mq_json", b"mq_json", "sorts", b"sorts"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_limit", b"_limit"]) -> typing_extensions.Literal["limit"] | None: ...

global___QueryMembersRequest = QueryMembersRequest

class QueryMembersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMBERS_FIELD_NUMBER: builtins.int
    @property
    def members(self) -> video.coordinator.client_v1_rpc.envelopes_pb2.MembersEnvelope: ...
    def __init__(
        self,
        *,
        members: video.coordinator.client_v1_rpc.envelopes_pb2.MembersEnvelope | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["members", b"members"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["members", b"members"]) -> None: ...

global___QueryMembersResponse = QueryMembersResponse

class GetCallEdgeServerRequest(google.protobuf.message.Message):
    """A request message for GetCallEdgeServer endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_CID_FIELD_NUMBER: builtins.int
    MEASUREMENTS_FIELD_NUMBER: builtins.int
    call_cid: builtins.str
    """Call CID to get SFU for"""
    @property
    def measurements(self) -> video.coordinator.edge_v1.edge_pb2.LatencyMeasurements:
        """Latency measurement results
        Optional
        """
    def __init__(
        self,
        *,
        call_cid: builtins.str = ...,
        measurements: video.coordinator.edge_v1.edge_pb2.LatencyMeasurements | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["measurements", b"measurements"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cid", b"call_cid", "measurements", b"measurements"]) -> None: ...

global___GetCallEdgeServerRequest = GetCallEdgeServerRequest

class GetCallEdgeServerResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CREDENTIALS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.client_v1_rpc.envelopes_pb2.CallEnvelope: ...
    @property
    def credentials(self) -> video.coordinator.edge_v1.edge_pb2.Credentials:
        """Call edge server credentials"""
    def __init__(
        self,
        *,
        call: video.coordinator.client_v1_rpc.envelopes_pb2.CallEnvelope | None = ...,
        credentials: video.coordinator.edge_v1.edge_pb2.Credentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "credentials", b"credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "credentials", b"credentials"]) -> None: ...

global___GetCallEdgeServerResponse = GetCallEdgeServerResponse

class CreateDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_FIELD_NUMBER: builtins.int
    @property
    def input(self) -> video.coordinator.push_v1.push_pb2.DeviceInput: ...
    def __init__(
        self,
        *,
        input: video.coordinator.push_v1.push_pb2.DeviceInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["input", b"input"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["input", b"input"]) -> None: ...

global___CreateDeviceRequest = CreateDeviceRequest

class CreateDeviceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_FIELD_NUMBER: builtins.int
    @property
    def device(self) -> video.coordinator.push_v1.push_pb2.Device: ...
    def __init__(
        self,
        *,
        device: video.coordinator.push_v1.push_pb2.Device | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["device", b"device"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device", b"device"]) -> None: ...

global___CreateDeviceResponse = CreateDeviceResponse

class DeleteDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___DeleteDeviceRequest = DeleteDeviceRequest

class DeleteDeviceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteDeviceResponse = DeleteDeviceResponse

class QueryDevicesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryDevicesRequest = QueryDevicesRequest

class QueryDevicesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICES_FIELD_NUMBER: builtins.int
    @property
    def devices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.coordinator.push_v1.push_pb2.Device]: ...
    def __init__(
        self,
        *,
        devices: collections.abc.Iterable[video.coordinator.push_v1.push_pb2.Device] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["devices", b"devices"]) -> None: ...

global___QueryDevicesResponse = QueryDevicesResponse

class SendEventRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_CID_FIELD_NUMBER: builtins.int
    EVENT_TYPE_FIELD_NUMBER: builtins.int
    call_cid: builtins.str
    """The call cid"""
    event_type: global___UserEventType.ValueType
    """The type of event"""
    def __init__(
        self,
        *,
        call_cid: builtins.str = ...,
        event_type: global___UserEventType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cid", b"call_cid", "event_type", b"event_type"]) -> None: ...

global___SendEventRequest = SendEventRequest

class SendEventResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SendEventResponse = SendEventResponse

class SendCustomEventRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_CID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DATA_JSON_FIELD_NUMBER: builtins.int
    call_cid: builtins.str
    """The call cid"""
    type: builtins.str
    """The type of event"""
    data_json: builtins.bytes
    """The data of the event"""
    def __init__(
        self,
        *,
        call_cid: builtins.str = ...,
        type: builtins.str = ...,
        data_json: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cid", b"call_cid", "data_json", b"data_json", "type", b"type"]) -> None: ...

global___SendCustomEventRequest = SendCustomEventRequest

class SendCustomEventResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SendCustomEventResponse = SendCustomEventResponse

class ReportCallStatsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_CID_FIELD_NUMBER: builtins.int
    STATS_JSON_FIELD_NUMBER: builtins.int
    call_cid: builtins.str
    """A concatenation of call type and call id with ":" as delimiter"""
    stats_json: builtins.bytes
    """A WebRTC Stats report encoded as a JSON string, as defined in https://www.w3.org/TR/webrtc/#dom-rtcstatsreport"""
    def __init__(
        self,
        *,
        call_cid: builtins.str = ...,
        stats_json: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cid", b"call_cid", "stats_json", b"stats_json"]) -> None: ...

global___ReportCallStatsRequest = ReportCallStatsRequest

class ReportCallStatsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReportCallStatsResponse = ReportCallStatsResponse

class ReportCallStatEventRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_CID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    MEDIA_STATE_CHANGED_FIELD_NUMBER: builtins.int
    call_cid: builtins.str
    """A concatenation of call type and call id with ":" as delimiter"""
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Event timestamp as RFC3339 string."""
    @property
    def media_state_changed(self) -> video.coordinator.stat_v1.stat_pb2.MediaStateChanged: ...
    def __init__(
        self,
        *,
        call_cid: builtins.str = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        media_state_changed: video.coordinator.stat_v1.stat_pb2.MediaStateChanged | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event", b"event", "media_state_changed", b"media_state_changed", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cid", b"call_cid", "event", b"event", "media_state_changed", b"media_state_changed", "timestamp", b"timestamp"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event", b"event"]) -> typing_extensions.Literal["media_state_changed"] | None: ...

global___ReportCallStatEventRequest = ReportCallStatEventRequest

class ReportCallStatEventResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReportCallStatEventResponse = ReportCallStatEventResponse

class GetCallStatsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_CID_FIELD_NUMBER: builtins.int
    call_cid: builtins.str
    """A concatenation of call type and call id with ":" as delimiter"""
    def __init__(
        self,
        *,
        call_cid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cid", b"call_cid"]) -> None: ...

global___GetCallStatsRequest = GetCallStatsRequest

class ReportIssueRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_CID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    call_cid: builtins.str
    """A concatenation of call type and call id with ":" as delimiter"""
    description: builtins.str
    """Optional description."""
    custom_json: builtins.bytes
    def __init__(
        self,
        *,
        call_cid: builtins.str = ...,
        description: builtins.str = ...,
        custom_json: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cid", b"call_cid", "custom_json", b"custom_json", "description", b"description"]) -> None: ...

global___ReportIssueRequest = ReportIssueRequest

class ReportIssueResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReportIssueResponse = ReportIssueResponse

class ReviewCallRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_CID_FIELD_NUMBER: builtins.int
    STARS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    call_cid: builtins.str
    """A concatenation of call type and call id with ":" as delimiter"""
    stars: builtins.float
    """Rating between 0 and 5 stars."""
    description: builtins.str
    """Optional description."""
    custom_json: builtins.bytes
    """Optional custom data."""
    def __init__(
        self,
        *,
        call_cid: builtins.str = ...,
        stars: builtins.float = ...,
        description: builtins.str = ...,
        custom_json: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cid", b"call_cid", "custom_json", b"custom_json", "description", b"description", "stars", b"stars"]) -> None: ...

global___ReviewCallRequest = ReviewCallRequest

class ReviewCallResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReviewCallResponse = ReviewCallResponse



import os
from typing import Any, Dict

import jwt
from google.protobuf.json_format import MessageToDict
from twirp.context import Context  # type: ignore

from .gen.video.coordinator.server_v1_rpc import server_rpc_pb2, server_rpc_twirp

try:
    from importlib import metadata  # type: ignore
except ImportError:  # for Python<3.8
    import importlib_metadata as metadata  # type: ignore

__version__ = metadata.version("stream_video")


def get_user_agent() -> str:
    return f"stream-python-client-{__version__}"


def get_default_header() -> Dict[str, str]:
    return {
        "Content-type": "application/json",
        "X-Stream-Client": get_user_agent(),
    }


class StreamVideo:
    def __init__(
        self, api_key: str, api_secret: str, timeout: float = 6.0, **options: Any
    ):
        self.base_url = "http://localhost:26991"
        if options.get("base_url"):
            self.base_url = options["base_url"]
        elif os.getenv("STREAM_VIDEO_URL"):
            self.base_url = os.environ["STREAM_VIDEO_URL"]

        self.timeout = timeout
        if os.getenv("STREAM_VIDEO_TIMEOUT"):
            self.timeout = float(os.environ["STREAM_VIDEO_TIMEOUT"])

        self.twirp = server_rpc_twirp.ServerRPCClient(
            address=self.base_url,
            timeout=self.timeout,
        )

        self.api_key = api_key
        self.api_secret = api_secret
        self.auth_token = jwt.encode(
            {"server": True}, self.api_secret, algorithm="HS256"
        )
        self.ctx = Context(
            headers={
                **get_default_header(),
                "api_key": self.api_key,
                "authorization": self.auth_token,
            }
        )

        self.options = options

    def get_app(self) -> Dict:
        return MessageToDict(
            self.twirp.GetApp(
                ctx=self.ctx,
                server_path_prefix="/rpc",
                request=server_rpc_pb2.GetAppRequest(),
            )
        )
